@@ -52,7 +52,7 @@ epilog = """---------- 使用帮助 ----------
             path.suffix.lower() in (".nfo", ".ass", ".ssa", ".srt", ".idx", ".sub", ".txt", ".vtt", ".smi")
         )'
 
-4. 把缓存保存到本地的 dbm 文件
+4. 把缓存保存到本地的 dbm 文件（不用担心性能问题，因为这种情况下会有 2 级缓存）
 
 .. code: console
 
@@ -60,12 +60,52 @@ epilog = """---------- 使用帮助 ----------
     import shelve
     cache = shelve.open("alist-cache")'
 
+.. 本地持久化缓存模块（推荐选用 dbm-like (类 dbm 的) 风格的模块）:
+
+    - dbm: https://docs.python.org/3/library/dbm.html
+    - shelve: https://docs.python.org/3/library/shelve.html
+    - sqlite3: https://docs.python.org/3/library/sqlite3.html
+    - rocksdict: https://pypi.org/project/rocksdict/
+    - speedict: https://pypi.org/project/speedict/
+    - unqlite: https://github.com/coleifer/unqlite-python
+    - vedis: https://github.com/coleifer/vedis-python
+    - lmdb: https://pypi.org/project/lmdb/
+    - lmdbm: https://pypi.org/project/lmdbm/
+    - semidbm: https://pypi.org/project/semidbm/
+    - pysos: https://pypi.org/project/pysos/
+    - wiredtiger: https://pypi.org/project/wiredtiger/
+    - sqlitedict: https://pypi.org/project/sqlitedict/
+    - tinydb: https://pypi.org/project/tinydb/
+    - diskcache: https://pypi.org/project/diskcache/
+    - h5py: https://github.com/h5py/h5py
+    - leveldb: https://github.com/jtolio/leveldb-py
+    - pickledb: https://github.com/patx/pickledb
+
+.. 序列化模块:
+
+    - pickle: https://docs.python.org/3/library/pickle.html
+    - marshal: https://docs.python.org/3/library/marshal.html
+    - json: https://docs.python.org/3/library/json.html
+    - orjson: https://pypi.org/project/orjson/
+    - ujson: https://pypi.org/project/ujson/
+
+.. 推荐阅读:
+
+    - https://stackoverflow.com/questions/47233562/key-value-store-in-python-for-possibly-100-gb-of-data-without-client-server
+    - https://charlesleifer.com/blog/completely-un-scientific-benchmarks-of-some-embedded-databases-with-python/
+    - https://docs.python.org/3/library/persistence.html
+    - https://stackoverflow.com/questions/4026359/memory-efficient-string-to-string-map-in-python-or-c
+
 5. 自定义生成的 strm，例如把 base-url 设置为 http://my.302.server
 
+.. code: console
+
     python-alist fuse --strm-predicate '*' --custom-strm 'http://my.302.server'
 
 6. 用 vlc 播放时直接打开播放器，而不是由 fuse 转发
 
+.. code: console
+
     python-alist fuse --direct-open-names vlc
 """
 
@@ -171,7 +211,7 @@ def main(args):
         👋 Welcome to use alist fuse 👏
 
     mounted at: {abspath(mount_point)!r}
-    fuse options: {options!r}
+    FUSE options: {options!r}
     """)
 
     if not exists(mount_point):
